==> nextcloud-12.0.7.tar.bz2: nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Taggar",
    "Update" : "Uppdatera",
    "Create" : "Skapa",
    "Select tag…" : "Välj tagg...",
    "Tagged files" : "Taggade filer",
    "Select tags to filter by" : "Välj taggar att filtrera med",
    "No tags found" : "Inga taggar hittades",
    "Please select tags to filter by" : "Vänligen välj taggar att filtrera med",
    "No files found for the selected tags" : "Inga filer hittades för de valda taggarna",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du raderade systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du raderade systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} raderade systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Collaborative tags" : "Samverkande taggar",
    "Create and edit collaborative tags. These tags affect all users." : "Skapa och redigera samverkanstaggar. Dessa taggar påverkar alla användare.",
    "Select tag …" : "Välj tagg ...",
    "Name" : "Namn",
    "Delete" : "Radera",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Reset" : "Återställ",
    "No files in here" : "Inga filer här inne",
    "No entries found in this folder" : "Ingenting hittades i denna mapp",
    "Size" : "Storlek",
    "Modified" : "Modifierad"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.6.tar.bz2: nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Taggar",
    "Update" : "Uppdatera",
    "Create" : "Skapa",
    "Select tag…" : "Välj tagg...",
    "Tagged files" : "Taggade filer",
    "Select tags to filter by" : "Välj taggar att filtrera med",
    "No tags found" : "Inga taggar hittades",
    "Please select tags to filter by" : "Vänligen välj taggar att filtrera med",
    "No files found for the selected tags" : "Inga filer hittades för de valda taggarna",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du raderade systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du raderade systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} raderade systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Collaborative tags" : "Samverkande taggar",
    "Select tag …" : "Välj tagg ...",
    "Name" : "Namn",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Delete" : "Radera",
    "Reset" : "Återställ",
    "No files in here" : "Inga filer här inne",
    "No entries found in this folder" : "Ingenting hittades i denna mapp",
    "Size" : "Storlek",
    "Modified" : "Modifierad",
    "Create and edit collaborative tags. These tags affect all users." : "Skapa och redigera samverkanstaggar. Dessa taggar påverkar alla användare."
},
"nplurals=2; plural=(n != 1);");
